@@ -6,6 +6,8 @@
 #include <R.h>
 #include <Rdefines.h>
 #include <Rinternals.h>
+#include <R_ext/GraphicsEngine.h>
+#include <R_ext/GraphicsDevice.h>
 
 #include <ft2build.h>
 #include FT_FREETYPE_H
@@ -13,12 +15,11 @@
 typedef struct fontDesc {
     FT_Library library;
     FT_Face face;
-} fontDesc;
+} FontDesc;
 
-typedef fontDesc* pfontDesc;
+typedef FontDesc* pFontDesc;
 
-SEXP swfLoadFont(SEXP fontPath);
-SEXP swfCleanFont(SEXP extPtr);
+FT_Face swfGetFTFace(const pGEcontext gc);
 
 #endif /* SWFFONT_H_INCLUDED */
 
